@@ -341,7 +341,7 @@ class GUI(Tk):
 			else:
 				print('Cannot do this - no dataset has been loaded.')
 				return
-		if not self.display and self.cfg['save_path'] is not None:
+		if self.cfg['save_path'] is None:
 			print('cfg["save_path"] is empty - please provide one!')
 			return
 		if not self.display:
@@ -436,7 +436,7 @@ class GUI(Tk):
 			else:
 				print('Cannot do this - no dataset has been loaded.')
 				return
-		if not self.display and self.cfg['save_path'] is not None:
+		if self.cfg['save_path'] is None:
 			print('cfg["save_path"] is empty - please provide one!')
 			return
 		if not self.display:
@@ -466,7 +466,7 @@ class GUI(Tk):
 			else:
 				print('Cannot do this - no dataset has been loaded.')
 				return
-		if not self.display and self.cfg['save_path'] is not None:
+		if self.cfg['save_path'] is None:
 			print('cfg["save_path"] is empty - please provide one!')
 			return
 		fn = os.path.join(self.cfg['save_path'],self.cfg['file_out'])
